@@ -532,7 +532,7 @@ def upload_folder(
         metadata=metadata,
         overwrite=overwrite,
         directory=target_folder,
-        data_set_id=dataset_id
+        dataset_id=dataset_id
     )
     os.remove(archive_name)
     logging.info(f"Folder content uploaded: {file_info=}")
@@ -651,7 +651,7 @@ def file_exists(external_id, directory, dataset_id=None):
     file_list = query_file_versions(
         directory_prefix=directory, 
         external_id_prefix=external_id,
-        uploaded=None, data_set_id=dataset_id
+        uploaded=None, dataset_id=dataset_id
     )
     if file_list.empty:
         logging.info(f"File with '{external_id=}' not found")
