@@ -126,7 +126,7 @@ class ServiceSettings():
     model_file: FilePath # if fields are modified
     req_file: FilePath
     test_file: Optional[FilePath]
-    artifact_folder: Path
+    artifact_folder: Optional[Path]
     info: dict
     platform: str = 'cdf'
     model_id: Optional[str] = None
